/* eslint-disable import/no-extraneous-dependencies */
import Vue from 'vue';
import { storiesOf } from '@storybook/vue';
import { withKnobs, boolean } from '@storybook/addon-knobs';

import Multiselect from 'vue-multiselect';
import centered from '@storybook/addon-centered';
Vue.component('multiselect', Multiselect);

const stories = storiesOf('Select', module);
const optionsSingle = ['Select option', 'options', 'selected', 'mulitple', 'label', 'searchable', 'clearOnSelect', 'hideSelected', 'maxHeight', 'allowEmpty', 'showLabels', 'onChange', 'touched'];
const optionsObject = [
  { value: 'CA', label: 'Canada', color: '#e75264' },
  { value: 'UK', label: 'United Kingdom', color: '#0087c5', $isDisabled: true }
];

stories.addDecorator(centered);
stories.addDecorator(withKnobs);
stories.add('Select - single', () => {
  return {
    components: { Multiselect },
    props: {
      options: { default: optionsSingle },
      multiple: { default: boolean('multiple', false) },
      searchable: { default: boolean('searchable', false) },
      disabled: { default: boolean('disabled', false) },
      loading: { default: boolean('loading', false) },
      value: { default: null }
    },
    template: `
      <div style='width:200px'>
      <multiselect
      v-model='value'
      :options='options'
      :multiple='multiple'
      :disabled='disabled'
      :show-labels='false'
      :loading='loading'
      :searchable='searchable'>
      </multiselect>
      <pre class="language-json"><code>{{ value  }}</code></pre></div>`
  };
}),
  {
    notes: 'A very simple component'
  };

stories.add(
  'Select - object',
  () => {
    return {
      components: { Multiselect },
      props: {
        options: { default: optionsObject },
        multiple: { default: boolean('multiple', false) },
        searchable: { default: boolean('searchable', false) },
        disabled: { default: boolean('disabled', false) },
        loading: { default: boolean('loading', false) },
        value: { default: null }
      },
      template: `
        <div style='width:200px'>
        <multiselect
        v-model='value'
        :options='options'
        :multiple='multiple'
        label='label'
        :disabled='disabled'
        :show-labels='false'
        :searchable='searchable'
        :loading='loading'
        track-by='value'>
        </multiselect>
        <pre class="language-json"><code>{{ value  }}</code></pre></div>`
    };
  },
  {
    notes: 'A very simple component'
  }
);

stories.add(
  'Select - custom template',
  () => {
    return {
      components: { Multiselect },
      props: {
        options: { default: optionsObject },
        multiple: { default: boolean('multiple', false) },
        searchable: { default: boolean('searchable', false) },
        disabled: { default: boolean('disabled', false) },
        loading: { default: boolean('loading', false) },
        value: { default: null }
      },
      template: `<div style='width:200px'>
    <multiselect
      v-model='value'
      :options='options'
      :multiple='multiple'
      label='label'
      :disabled='disabled'
      :show-labels='false'
      :searchable='searchable'
      :loading='loading'
      track-by='value'>
    <template slot=\"singleLabel\" slot-scope=\"{ option }\"><span class='sh-select-option-indicator' :style='{background:option.color }'></span> {{ option.label }}</template>
    <template slot=\"option\" slot-scope=\"{ option }\"><span class='sh-select-option-indicator' :style='{background:option.color }'></span> {{ option.label }}</template>
    </multiselect>
    <pre class=\"language-json\"><code>{{ value  }}</code></pre>
    </div>`
    };
  },
  {
    notes: 'A very simple component'
  }
);
