/* eslint-disable import/no-extraneous-dependencies */
import {storiesOf} from '@storybook/vue'
import {action} from '@storybook/addon-actions'
import {
  withKnobs,
  boolean
} from '@storybook/addon-knobs';

import ShAutocompleter from '../components/sh-autocompleter/ShAutocompleter';
import ShImage from '../components/sh-image/ShImage';
import centered from "@storybook/addon-centered";

const stories = storiesOf('Autocompleter', module);
const data = [
  {name: 'Shoplo shirt', image: './bag.png'},
  {name: 'Shoplo bag', image: './pen.png'},
  {name: 'Shoplo notebook', image: './notebook.jpg'},
  {name: 'Shoplo socks', image: './bag.png'},
  {name: 'Shoplo notebook', image: './pen.png'}
  ];

stories.addDecorator(withKnobs);
stories.addDecorator(centered);
stories.add('ShAutocompleter', () => {
  return {
    components: {ShAutocompleter, ShImage},
    props: {
      data: { default: data },
      value: { default: '' },
      selected: { default: null },
      loading: { default: boolean('loading', false) }
    },
    template: `<div style="width: 800px">
  <p class="content" v-if="selected"><b>Selected:</b> {{ selected.name }}</p>
  <ShAutocompleter
    v-model="value"
    inputPlaceholder="Search..."
    :data="filteredDataArray"
    field="products"
    :loading="loading"
    @typing="onTyping"
    @select="option => selected = option">
    <template slot-scope="props">
      <ShImage imageSize="50" :imageSrc="props.option.image"></ShImage>
      <span>{{ props.option.name }}</span>
    </template>
    <template slot="empty">No results found</template>
  </ShAutocompleter>
</div>`,
    computed: {
      filteredDataArray() {
        return this.data.filter((option) => {
          if (this.value) {
            return option.name.toString().toLowerCase().indexOf(this.value.toLowerCase()) >= 0;
          }
        })
      }
    },
    methods: {
      onTyping: action('onTyping')
    }
  }
},{
  notes: 'A very simple component',
});
