/* eslint-disable import/no-extraneous-dependencies */
import {storiesOf} from '@storybook/vue'
import {action} from '@storybook/addon-actions'
import {
  withKnobs,
  text,
  boolean,
} from '@storybook/addon-knobs';

import ShCategoriesSelect from '../components/sh-categories-select/ShCategoriesSelect';
import centered from "@storybook/addon-centered";
import i18n from '../../config/storybook/locale';

const categories = [
  {
    id: '5505a628-9766-4724-aa44-474f53dcd6f1',
    name: 'parent-1 name',
    slug: 'parent-1-url',
    position: 1,
    description: 'parent-1 description',
    parentId: null,
    image: 'https://non-existent.com/logo-1.png',
    children: [
      {
        id: '3a33a21d-348f-4b3f-a876-0a969116dff2',
        name: 'child-2 name',
        slug: 'child-2-url',
        position: 1,
        description: 'child-2 description',
        parentId: '5505a628-9766-4724-aa44-474f53dcd6f1',
        image: 'https://non-existent.com/logo-2.png',
        children: [
          {
            id: 'feb8873f-9cec-476c-af82-3e7cbe08538f',
            name: 'child-4 name',
            slug: 'child-4-url',
            position: 1,
            description: 'child-4 description',
            parentId: '3a33a21d-348f-4b3f-a876-0a969116dff2',
            image: 'https://non-existent.com/logo-4.png',
            children: [],
            metaTitle: 'child-4 meta title',
            metaDescription: 'child-4 meta description',
            metaKeywords: ['child-4','meta','keywords'],
            createdAt: '2019-01-01T00:00:04+01:00',
            updatedAt: '2019-01-01T00:10:04+01:00'
          },
          {
            id: 'feb8873f-9cec-476c-af82-3e7cbe08538213',
            name: 'child-4-5 name',
            slug: 'child-4-5-url',
            position: 1,
            description: 'child-4 description',
            parentId: '3a33a21d-348f-4b3f-a876-0a969116dff2',
            image: 'https://non-existent.com/logo-4.png',
            children: [],
            metaTitle: 'child-4 meta title',
            metaDescription: 'child-4 meta description',
            metaKeywords: ['child-4','meta','keywords'],
            createdAt: '2019-01-01T00:00:04+01:00',
            updatedAt: '2019-01-01T00:10:04+01:00'
          }
        ],
        metaTitle: 'child-2 meta title',
        metaDescription: 'child-2 meta description',
        metaKeywords: ['child-2','meta','keywords'],
        createdAt: '2019-01-01T00:00:02+01:00',
        updatedAt: '2019-01-01T00:10:02+01:00'
      },
      {
        id: '1339ca40-1925-4126-b47a-948d53ab2ba7',
        name: 'child-3 name',
        slug: 'child-3-url',
        position: 2,
        description: 'child-3 description',
        parentId: '5505a628-9766-4724-aa44-474f53dcd6f1',
        image: 'https://non-existent.com/logo-3.png',
        children: [],
        metaTitle: 'child-3 meta title',
        metaDescription: 'child-3 meta description',
        metaKeywords: ['child-3','meta','keywords'],
        createdAt: '2019-01-01T00:00:03+01:00',
        updatedAt: '2019-01-01T00:10:03+01:00'
      }
    ],
    metaTitle: 'parent-1 meta title',
    metaDescription: 'parent-1 meta description',
    metaKeywords: ['parent-1','meta','keywords'],
    createdAt: '2019-01-01T00:00:01+01:00',
    updatedAt: '2019-01-01T00:10:01+01:00'
  },
  {
    id: 'c3340a19-8026-497d-8521-b62ed7c2c307',
    name: 'parent-5 name',
    slug: 'parent-5-url',
    position: 2,
    description: 'parent-5 description',
    parentId: null,
    image: 'https://non-existent.com/logo-5.png',
    children: [],
    metaTitle: 'parent-5 meta title',
    metaDescription: 'parent-5 meta description',
    metaKeywords: ['parent-5','meta','keywords'],
    createdAt: '2019-01-01T00:00:05+01:00',
    updatedAt: '2019-01-01T00:10:05+01:00'
  }
];
const stories = storiesOf('Select categories', module);
stories.addDecorator(withKnobs);
stories.addDecorator(centered);
stories.add('Select categories', () => {
  return {
    i18n: i18n,
    components: {ShCategoriesSelect},
    props: {
      usePredefinedCategories: { default: boolean('usePredefinedCategories', false) },
      categories: { default: categories },
      selectedCategories: { default: [] },
      predefinedCategories: { default: ["5505a628-9766-4724-aa44-474f53dcd6f1", "feb8873f-9cec-476c-af82-3e7cbe08538213", "3a33a21d-348f-4b3f-a876-0a969116dff2"] }
    },
    template: `
    <ShCategoriesSelect
      v-model="usePredefinedCategories ? predefinedCategories : selectedCategories"
      :categories="categories"
    ></ShCategoriesSelect>`
  }
},{
  notes: 'A very simple component',
});
