/* eslint-disable import/no-extraneous-dependencies */
import {storiesOf} from '@storybook/vue'
import {action} from '@storybook/addon-actions'
import {
  withKnobs,
  text,
  boolean,
} from '@storybook/addon-knobs';

import ShCheckbox from '../components/sh-checkbox/ShCheckbox';
import ShCheckboxGroup from '../components/sh-checkbox/ShCheckboxGroup';
import centered from "@storybook/addon-centered";

const checkboxGroupListTypeOptions = {
  'inline': 'inline',
  'block': 'block'
};

const stories = storiesOf('Checkbox', module);
stories.addDecorator(withKnobs);
stories.addDecorator(centered);
stories.add('Regular checkbox', () => {
  return {
    components: {ShCheckbox},
    props: {
      checkboxLabelContent: { default: text('checkboxLabelContent', 'Checkbox label content') },
      checkboxName: { default: text('checkboxName', 'sh_checkbox') },
      checkboxValue: { default: text('checkboxValue', 'Checkbox value') },
      checkboxTrueValue: { default: text('checkboxTrueValue', 'Checkbox true value') },
      checkboxFalseValue: { default: text('checkboxFalseValue', 'Checkbox false value') },
      disabled: { default: boolean('disabled', false) },
      isRequired: { default: boolean('isRequired', false) },
      isIndeterminate: { default: boolean('isIndeterminate', false) },
      isSwitch: { default: boolean('isSwitch', false) },
      checkboxLabelContent2: { default: text('checkboxLabelContent2', 'Checkbox 2 label content') },
      checkboxValue2: { default: text('checkboxValue2', 'Checkbox 2 value') },
      checkboxTrueValue2: { default: text('checkboxTrueValue2', 'Checkbox 2 true value') },
      checkboxFalseValue2: { default: text('checkboxFalseValue2', 'Checkbox 2 false value') },
      value: { default: null },
    },
    template: "<div>" +
      "<ShCheckbox " +
      ":checkboxLabelContent='checkboxLabelContent'" +
      ":checkboxName='checkboxName' " +
      ":checkboxValue='checkboxValue'" +
      ":checkboxTrueValue='checkboxTrueValue'" +
      ":checkboxFalseValue='checkboxFalseValue'" +
      ":disabled='disabled'" +
      ":isIndeterminate='isIndeterminate'" +
      ":isRequired='isRequired'" +
      ":isSwitch='isSwitch'" +
      "v-model='value'>" +
      "</ShCheckbox>" +
      "<pre class=\"language-json\"><code>{{ value }}</code></pre>" +
      "</div>"
  }
},{
  notes: 'A very simple component',
});
stories.add('Switch', () => {
  return {
    components: {ShCheckbox},
    props: {
      checkboxLabelContent: { default: text('checkboxLabelContent', 'Switch label content') },
      checkboxName: { default: text('checkboxName', 'sh_checkbox') },
      checkboxValue: { default: text('checkboxValue', 'Switch value') },
      checkboxTrueValue: { default: text('checkboxTrueValue', 'Switch true value') },
      checkboxFalseValue: { default: text('checkboxFalseValue', 'Switch false value') },
      disabled: { default: boolean('disabled', false) },
      isRequired: { default: boolean('isRequired', false) },
      isSwitch: { default: boolean('isSwitch', true) },
      value: { default: null },
    },
    template: "<div>" +
      "<ShCheckbox " +
      ":checkboxLabelContent='checkboxLabelContent'" +
      ":checkboxName='checkboxName' " +
      ":checkboxValue='checkboxValue'" +
      ":checkboxTrueValue='checkboxTrueValue'" +
      ":checkboxFalseValue='checkboxFalseValue'" +
      ":disabled='disabled'" +
      ":isRequired='isRequired'" +
      ":isSwitch='isSwitch'" +
      "v-model='value'>" +
      "</ShCheckbox>" +
      "<pre class=\"language-json\"><code>{{ value }}</code></pre>" +
      "</div>"
  }
},{
  notes: 'A very simple component',
});

stories.add('Checkbox group', () => {
  return {
    components: {ShCheckbox, ShCheckboxGroup},
    props: {
      isWithColumns: { default: boolean('isWithColumns', true) },
      value: { default: [] },
    },
    template: `<div>
      <ShCheckboxGroup :isWithColumns="isWithColumns">
        <ShCheckbox
        class="sm-12 md-3 lg-4 column"
        checkboxLabelContent="Checkbox 1 label content"
        checkboxName="checkbox_name" 
        checkboxValue="Checkbox 1 value"
        checkboxTrueValue="Checkbox 1 true value"
        checkboxFalseValue="Checkbox 1 false value"
        v-model="value">
        </ShCheckbox>
        <ShCheckbox
        class="sm-12 md-3 lg-4 column"
        checkboxLabelContent="Checkbox 2 label content"
        checkboxName="checkbox_name" 
        checkboxValue="Checkbox 2 value"
        checkboxTrueValue="Checkbox 2 true value"
        checkboxFalseValue="Checkbox 2 false value"
        v-model="value">
        </ShCheckbox>
        <ShCheckbox
        class="sm-12 md-3 lg-4 column"
        checkboxLabelContent="Checkbox 3 label content"
        checkboxName="checkbox_name" 
        checkboxValue="Checkbox 3 value"
        checkboxTrueValue="Checkbox 3 true value"
        checkboxFalseValue="Checkbox 3 false value"
        v-model="value">
        </ShCheckbox>
      </ShCheckboxGroup>
      <pre class="language-json"><code>{{ value }}</code></pre>
    </div>`
  }
},{
  notes: 'A very simple component',
});
