/* eslint-disable import/no-extraneous-dependencies */
import {storiesOf} from '@storybook/vue'
import {action} from '@storybook/addon-actions'
import {
  withKnobs,
  text,
  boolean,
  select,
  number,
} from '@storybook/addon-knobs';

import ShModal from '../components/sh-modal/ShModal';
import ShButton from '../components/sh-button/ShButton';
import centered from "@storybook/addon-centered";
const animationTypes = {
  'zoom-out': 'zoom-out',
  'zoom-in': 'zoom-in',
  'fade': 'fade'
};
const stories = storiesOf('Dialog', module);

stories.addDecorator(withKnobs);
stories.addDecorator(centered);
stories.add('Confirm', () => {
  return {
    components: {ShModal, ShButton},
    props: {
      active: { default: boolean('active', false) },
      animation: { default: select('animation', animationTypes, 'zoom-out') },
      width: { default: number('width', 400) },
      hasModalCard: { default: boolean('hasModalCard', true) },
      content: { default: text('content', 'You have unsaved changes. Are you sure to leave this page?') },
      modalCardHeader: { default: text('modalCardHeader', 'Confirmation') },
      modalCardHeaderIcon: { default: boolean('modalCardHeaderIcon', true) },
      modalCardConfirm: { default: text('modalCardConfirm', 'Confirm') },
      modalCardCancel: { default: text('modalCardCancel', 'Cancel') },
    },
    template: `
  <div>
  <ShButton @click="showConfirm" buttonContent="Show alert"></ShButton>
</div>`,
    methods: {
      showConfirm() {
        this.$dialog.confirm({
          content: this.content,
          animation: this.animation,
          width: this.width,
          modalCardHeader: this.modalCardHeader,
          modalCardHeaderIcon: this.modalCardHeaderIcon,
          modalCardConfirm: this.modalCardConfirm,
          modalCardCancel: this.modalCardCancel,
          onConfirm: () => {
            console.log('confirm')
          }
        });
      }
    }
  }
},{
  notes: 'A very very simple component',
});

stories.add('Alert', () => {
  return {
    components: {ShModal, ShButton},
    props: {
      active: { default: boolean('active', false) },
      animation: { default: select('animation', animationTypes, 'zoom-out') },
      width: { default: number('width', 400) },
      hasModalCard: { default: boolean('hasModalCard', true) },
      content: { default: text('content', 'Save the settings to proceed') },
      modalCardHeader: { default: text('modalCardHeader', 'Alert') },
      modalCardHeaderIcon: { default: boolean('modalCardHeaderIcon', true) },
      modalCardConfirm: { default: text('modalCardConfirm', 'OK') },
    },
    template: `
  <div>
  <ShButton @click="showAlert" buttonContent="Show alert"></ShButton>
</div>
`,
    methods: {
      showAlert() {
        this.$dialog.alert({
          content: this.content,
          animation: this.animation,
          width: this.width,
          modalCardHeader: this.modalCardHeader,
          modalCardHeaderIcon: this.modalCardHeaderIcon,
          modalCardConfirm: this.modalCardConfirm,
          onConfirm: () => {
            console.log('confirm')
          }
        });
      }
    }
  }
},{
  notes: 'A very very simple component',
});
