/* eslint-disable import/no-extraneous-dependencies */
import { storiesOf } from '@storybook/vue';
import { action } from '@storybook/addon-actions';
import { withKnobs, text, boolean, select } from '@storybook/addon-knobs';

import ShDropdown from '../components/sh-dropdown/ShDropdown';
import ShDropdownItem from '../components/sh-dropdown/ShDropdownItem';
import ShButton from '../components/sh-button/ShButton';

const stories = storiesOf('Dropdown', module);
import IconsList from '../helpers/IconsList';
import centered from '@storybook/addon-centered';

const positions = {
  top: 'top',
  'top-start': 'top-start',
  'top-end': 'top-end',
  bottom: 'bottom',
  'bottom-start': 'bottom-start',
  'bottom-end': 'bottom-end',
  left: 'left',
  'left-start': 'left-start',
  'left-end': 'left-end',
  right: 'right',
  'right-start': 'right-start',
  'right-end': 'right-end'
};

const triggers = {
  click: 'click',
  hover: 'hover'
};

const boundaries = {
  scrollParent: 'scrollParent',
  window: 'window',
  viewport: 'viewport'
};

const tooltipTypes = {
  default: 'default',
  info: 'info',
  warning: 'warning',
  error: 'error'
};

stories.addDecorator(withKnobs);
stories.addDecorator(centered);
stories.add(
  'Dropdown',
  () => {
    return {
      components: { ShDropdown, ShDropdownItem, ShButton },
      props: {
        value: { default: boolean('value', true) },
        trigger: { type: String, default: select('triggers', triggers, 'click') },
        delayOnMouseOver: { default: text('delayOnMouseOver', '10') },
        delayOnMouseOut: { default: text('delayOnMouseOut', '10') },
        boundariesElement: { type: String, default: select('boundaries', boundaries, 'scrollParent') },
        position: { type: String, default: select('position', positions, 'bottom-end') },
        forceShow: { default: boolean('forceShow', false) },
        forceHide: { default: boolean('forceHide', false) },
        appendToBody: { default: boolean('appendToBody', false) },
        visibleArrow: { default: boolean('visibleArrow', false) },
        stopPropagation: { default: boolean('stopPropagation', false) },
        preventDefault: { default: boolean('preventDefault', false) },
        mobileModal: { default: boolean('is modal on mobile', false) },
        disabled: { default: boolean('disabled', false) },
        hoverable: { default: boolean('hoverable', false) },
        itemDisabled: { default: boolean('item disabled', false) },
        paddingless: { default: boolean('paddingless', false) }
      },
      template: `<sh-dropdown 
      v-model='value'
      :trigger='trigger'
      :disabled='disabled'
      :mobileModal='mobileModal'
      :position='position'
      :delayOnMouseOver='delayOnMouseOver'
      :delayOnMouseOut='delayOnMouseOut'
      :forceShow="forceShow"
      :forceHide="forceHide"
      :appendToBody="appendToBody"
      :visibleArrow="visibleArrow"
      :stopPropagation="stopPropagation"
      :preventDefault="preventDefault"
    >
    <sh-dropdown-item  :value='true' :disabled='itemDisabled' :paddingless='paddingless'>Action</sh-dropdown-item>
    <sh-dropdown-item :value='false' :paddingless='paddingless'  class=\"no-hover custom-item\">ddd</sh-dropdown-item>
    <sh-button slot='reference'
      buttonContent='Open'
    >
    </sh-button>
    </sh-dropdown>`,
      methods: { action: action('clicked') }
    };
  },
  {
    notes: 'A very very simple component'
  }
);

stories.add(
  'Tooltip',
  () => {
    return {
      components: { ShDropdown, ShDropdownItem, ShButton },
      props: {
        trigger: { type: String, default: select('triggers', triggers, 'hover') },
        isTooltip: { default: boolean('isTooltip', false) },
        tooltipType: { type: String, default: select('tooltipType', tooltipTypes, 'error') },
        tooltipIcon: { type: String, default: select('tooltipIcon', IconsList, 'sh-icon-warning') },
        tooltipTitle: { default: text('tooltipTitle', 'Lorem ipsum dolor sit amet enim.') },
        tooltipContent: {
          default: text(
            'tooltipContent',
            'Lorem ipsum dolor sit amet enim. Etiam ullamcorper. Suspendisse a pellentesque dui, non felis. Maecenas malesuada elit lectus felis, malesuada ultricies.'
          )
        },
        position: { type: String, default: select('position', positions, 'top') }
      },
      template: `
    <ShDropdown
    :trigger="trigger"
    :tooltipType="tooltipType" 
    :isTooltip="true" 
    :position="position"
    :options="{
    modifiers: {
    offset: { offset: '0,10px' },
    preventOverflow:  { enabled: false },
    }
    }"
    >
    <ShDropdownItem
     :isTooltip="true" 
     :tooltipContent="tooltipContent" 
    
     :tooltipTitle="tooltipTitle"
     >
     </ShDropdownItem>
    <div slot="reference">Hover</div>
    </ShDropdown>`,
      methods: { action: action('clicked') }
    };
  },
  {
    notes: 'A very very simple component'
  }
);
