/* eslint-disable import/no-extraneous-dependencies */
import { storiesOf } from '@storybook/vue';
import { action } from '@storybook/addon-actions';
import { withKnobs, text, boolean, select } from '@storybook/addon-knobs';

import ShInput from '../components/sh-input/ShInput';
import ShIcon from '../components/sh-icon/ShIcon';
import IconsList from '../helpers/IconsList';
import centered from '@storybook/addon-centered';

const stories = storiesOf('Input', module);

const inputTypesOptions = {
  text: 'text',
  number: 'number',
  email: 'email',
  password: 'password'
};
const inputSizeOptions = {
  regular: '',
  large: 'large'
};
const maskTypes = {
  none: '',
  money: {
    decimal: '.',
    thousands: '',
    prefix: '',
    suffix: '',
    precision: 2
  }
};

stories.addDecorator(centered);
stories.addDecorator(withKnobs);
stories.add(
  'ShInput',
  () => {
    return {
      components: { ShInput, ShIcon },
      props: {
        inputType: { default: select('inputType', inputTypesOptions, '') },
        value: { default: text('value', '') },
        inputSize: { default: select('inputSize', inputSizeOptions, '') },
        inputName: { default: text('inputName', 'inputName') },
        disabled: { default: boolean('disabled', false) },
        isReadonly: { default: boolean('isReadonly', false) },
        isLoading: { default: boolean('isLoading', false) },
        inputSuffix: { default: text('inputSuffix', '') },
        inputPrefix: { default: text('inputPrefix', '') },
        inputButtonContent: { default: text('inputButtonContent', 'Send') },
        inputPlaceholder: { default: text('inputPlaceholder', '') },
        iconName: { default: select('iconName', IconsList, 'sh-icon-arrow-back') }
      },
      template: `<ShInput 
    :inputType="inputType"
    v-model="value"
    :inputName="inputName"
    :inputSize="inputSize"
    :disabled="disabled"
    :isReadonly="isReadonly"
    :isLoading="isLoading"
    :inputIcon="iconName"
    :inputSuffix="inputSuffix"
    :inputPrefix="inputPrefix"
    :inputPlaceholder="inputPlaceholder"
    :inputButtonContent="inputButtonContent"
    >
    </ShInput>
  `,
      methods: { action: action('clicked') }
    };
  },
  {
    notes: 'A very very simple component'
  }
);
