/* eslint-disable import/no-extraneous-dependencies */
import {storiesOf} from '@storybook/vue'
import {action} from '@storybook/addon-actions'
import {
  withKnobs,
  text,
  boolean,
  select,
  number,
} from '@storybook/addon-knobs';

import ShModal from '../components/sh-modal/ShModal';
import ShButton from '../components/sh-button/ShButton';
import centered from "@storybook/addon-centered";

const animationTypes = {
  'zoom-out': 'zoom-out',
  'zoom-in': 'zoom-in',
  'fade': 'fade'
};
const stories = storiesOf('Modal', module);

stories.addDecorator(withKnobs);
stories.addDecorator(centered);
stories.add('Basic modal', () => ({
  components: {ShModal, ShButton},
  props: {
    active: {default: boolean('active', false)},
    animation: {default: select('animation', animationTypes, 'zoom-out')},
    width: {default: number('width', 720)},
    hasModalCard: {default: boolean('hasModalCard', true)},
    content: {default: text('content', 'Sample content')},
    modalCardHeader: {default: text('modalCardHeader', 'Sample modal title')},
    modalCardHeaderIcon: {default: boolean('modalCardHeaderIcon', true)},
    modalCardConfirm: {default: text('modalCardConfirm', 'Confirm')},
    modalCardCancel: {default: text('modalCardCancel', 'Cancel')},
  },
  template: `
  <div>
  <ShButton @click="active = !active" buttonContent="Modal open"></ShButton>
  <ShModal 
  :active.sync="active" 
  :animation="animation"
  :width="width"
  :hasModalCard="hasModalCard"
  :content="content"
  :modalCardHeader="modalCardHeader"
  :modalCardHeaderIcon="modalCardHeaderIcon"
  :modalCardConfirm="modalCardConfirm"
  :modalCardCancel="modalCardCancel"
  >
</ShModal>
</div>
`,
  methods: {
    onCancel() {
      alert('cancel')
    }
  }
}), {
  notes: 'A very very simple component',
});

stories.add('Custom HTML', () => ({
  components: {ShModal, ShButton},
  props: {
      isComponentModalActive: { default: false },
      active: { default: boolean('active', false) },
      animation: { default: select('animation', animationTypes, 'zoom-out') },
      width: { default: number('width', 720) },
      hasModalCard: { default: boolean('hasModalCard', true) },
      content: { default: text('content', '') },
      modalCardHeader: { default: text('modalCardHeader', '') },
      modalCardHeaderIcon: { default: boolean('modalCardHeaderIcon', false) },
      modalCardConfirm: { default: text('modalCardConfirm', '') },
      modalCardCancel: { default: text('modalCardCancel', '') },
  },
  template: `
  <div>
  <ShButton @click="active = !active" buttonContent="Modal open"></ShButton>
  <ShModal 
  :active.sync="active" 
  :animation="animation"
  :width="width"
  :hasModalCard="hasModalCard"
  :content="content"
  :modalCardHeader="modalCardHeader"
  :modalCardHeaderIcon="modalCardHeaderIcon"
  :modalCardConfirm="modalCardConfirm"
  :modalCardCancel="modalCardCancel"
  >
  <div>
    <h1>Custom h1 tag</h1>
    <p>Description</p>
  </div>
</ShModal>
</div>
`,
  methods: {
    onCancel() {
      alert('cancel')
    }
  }
}), {
  notes: 'A very very simple component',
});
