/* eslint-disable import/no-extraneous-dependencies */
import { storiesOf } from '@storybook/vue';
import { withKnobs, text, boolean, select } from '@storybook/addon-knobs';

import ShNotificationBanner from '../components/sh-notification-banner/ShNotificationBanner';
import { action } from '@storybook/addon-actions';

const stories = storiesOf('NotificationBanner', module);
const notificationBannerIconOptions = {
  none: '',
  info: 'sh-icon-info-2',
  warning: 'sh-icon-warning',
  check: 'sh-icon-check-2'
};
const notificationBannerImageOptions = {
  none: '',
  lifebuoy: './lifebuoy.svg',
  spaceship: './calendar.svg',
  bell: './bell.svg'
};
const notificationBannerTypeOptions = {
  success: 'success',
  warning: 'warning',
  error: 'error',
  'info-light': 'info-light',
  info: 'info',
  'info-dark': 'info-dark',
  'info-blue': 'info-blue'
};
const notificationBannerbuttonSizeOptions = {
  regular: '',
  small: 'small'
};
const notificationBannerButtonColorOptions = {
  primary: 'primary',
  secondary: 'secondary',
  'clear-blue': 'clear-blue',
  'clear-gray': 'clear-gray',
  'clear-white': 'clear-white'
};

stories.addDecorator(withKnobs);
stories.add(
  'Simple notification',
  () => {
    return {
      components: {ShNotificationBanner},
      props: {
        notificationBannerIcon: {
          default: select('notificationBannerIcon', notificationBannerIconOptions, 'sh-icon-info-2')
        },
        notificationBannerType: {default: select('notificationBannerType', notificationBannerTypeOptions, 'warning')},
        isClosable: {default: boolean('isClosable', true)},
        isBorderless: {default: boolean('isBorderless', false)},
        isShadowless: {default: boolean('isShadowless', false)},
        notificationBannerButtonContent: {default: text('notificationBannerButtonContent', 'Manage')}
      },
      template:
        '<ShNotificationBanner ' +
        ":notificationBannerIcon='notificationBannerIcon'" +
        ":notificationBannerType='notificationBannerType'" +
        ":notificationBannerButtonContent='notificationBannerButtonContent'" +
        ":isClosable='isClosable'" +
        ":isBorderless='isBorderless'" +
        ":isShadowless='isShadowless'" +
        "@notificationCloseClicked='closeClicked'" +
        "@notificationButtonClicked='buttonClicked'>" +
        "<p slot='content'>Lorem ipsum dolor sit amet enim. Etiam ullamcorper. Suspendisse a pellentesque dui, non felis.<br>" +
        'Maecenas malesuada elit lectus felis, malesuada ultricies.</p>' +
        '</ShNotificationBanner>',
      methods: {
        closeClicked: action('closeClicked'),
        buttonClicked: action('buttonClicked')
      }
    }
  },
  {
    notes: 'A very simple component'
  }
);

stories.add(
  'Large notification with image',
  () => {
    return {
      components: {ShNotificationBanner},
      props: {
        notificationBannerImage: {default: './bell.svg'},
        notificationBannerButtonColor: {
          default: select('notificationBannerButtonColor', notificationBannerButtonColorOptions, 'primary')
        },
        notificationBannerButtonSize: {
          default: select('notificationBannerButtonSize', notificationBannerbuttonSizeOptions, 'small')
        },
        notificationBannerButtonContent: {default: text('notificationBannerButtonContent', 'Otrzymaj pełny dostęp')},
        notificationBannerType: {default: 'info'}
      },
      template:
        '<ShNotificationBanner ' +
        ":notificationBannerImage='notificationBannerImage'" +
        ":notificationBannerType='notificationBannerType'" +
        ":notificationBannerButtonContent='notificationBannerButtonContent'" +
        ":notificationBannerButtonSize='notificationBannerButtonSize'" +
        ":notificationBannerButtonColor='notificationBannerButtonColor'" +
        ":hasColoredButtons='false'" +
        "@notificationButtonClicked='buttonClicked'>" +
        "<div slot='content'>" +
        "<h4 class='sh-title'>Poznaj najwygodniejszy system płatności</h4>" +
        "<p class='sh-description'>Tylko 1.69% prowizji, 0 skomplikowanych umów, bez pośredników<br>" +
        'Pierwsze 3 miesiące 0% prowizji!</p>' +
        '</div>' +
        '</ShNotificationBanner>',
      methods: {
        buttonClicked: action('buttonClicked')
      }
    }
  },
  {
    notes: 'A very simple component'
  }
);

stories.add(
  'Small notification with image',
  () => {
    return {
      components: {ShNotificationBanner},
      props: {
        notificationBannerImage: {default: './calendar.svg'},
        notificationBannerButtonColor: {
          default: select('notificationBannerButtonColor', notificationBannerButtonColorOptions, 'secondary')
        },
        notificationBannerButtonSize: {
          default: select('notificationBannerButtonSize', notificationBannerbuttonSizeOptions, 'small')
        },
        notificationBannerButtonContent: {
          default: text('notificationBannerButtonContent', 'Podłącz swoje kanały sprzedaży')
        },
        notificationBannerType: {default: 'info-dark'},
        isNotificationBannerWithSmallImage: {default: true}
      },
      template:
        '<ShNotificationBanner ' +
        ":notificationBannerImage='notificationBannerImage'" +
        ":notificationBannerType='notificationBannerType'" +
        ":notificationBannerButtonContent='notificationBannerButtonContent'" +
        ":notificationBannerButtonSize='notificationBannerButtonSize'" +
        ":notificationBannerButtonColor='notificationBannerButtonColor'" +
        ":hasColoredButtons='false'" +
        ":isNotificationBannerWithSmallImage='isNotificationBannerWithSmallImage'" +
        "@notificationButtonClicked='buttonClicked'>" +
        "<p slot='content'>Przeglądasz próbny asortyment. Podłącz Swoje kanały sprzedaży, aby zresetować <br>" +
        'próbny asortyment i testować wszystkie funkcje Shoplo Multichannel.</p>' +
        '</div>' +
        '</ShNotificationBanner>',
      methods: {
        buttonClicked: action('buttonClicked')
      }
    }
  },
  {
    notes: 'A very simple component'
  }
);
