/* eslint-disable import/no-extraneous-dependencies */
import {storiesOf} from '@storybook/vue'
import {action} from '@storybook/addon-actions'
import {
  withKnobs,
  text,
  boolean,
  select,
} from '@storybook/addon-knobs';

import ShProductCard from '../components/sh-product-card/ShProductCard';
import ShDropdown from '../components/sh-dropdown/ShDropdown';
import ShDropdownItem from '../components/sh-dropdown/ShDropdownItem';
import ShButton from '../components/sh-button/ShButton';

const stories = storiesOf('Product card', module);
import centered from "@storybook/addon-centered";

const dropdownOptions = [
  { value: 'delete', label: 'Delete' },
  { value: 'set-as-first', label: 'Set as first' },
  { value: 'set-as-last', label: 'Set as last' }
];

stories.addDecorator(withKnobs);
stories.addDecorator(centered);
stories.add('Product card', () => ({
  components: {ShProductCard, ShDropdown, ShDropdownItem, ShButton},
  props: {
      product: { default: {
        image: text('imageSrc', './bag.png'),
        name: text('productName', 'Shoplo bag - color black'),
        isActive: boolean('isProductActive', true)
      }},
    isDraggable: { default: boolean('isDraggable', true) },
    isCheckable: { default: boolean('isCheckable', true) },
    isSelected: { default: boolean('isSelected', false) },
    dropdownOptions: dropdownOptions
  },
  template: `<ShProductCard 
style="width: 141px"
:product="product"
:isDraggable="isDraggable"
:isCheckable="isCheckable"
:isSelected="isSelected"
>
  <ShDropdown
      slot="dropdown"
      :mobileModal="true"
      :visibleArrow="true"
      position="bottom"
      :appendToBody="true"
      :options="{
    modifiers: {
    offset: { offset: '0,10px' },
    }
    }"
    >
      <ShDropdownItem
        v-for="(option, i) in dropdownOptions"
        :value="option.value"
        :key="i"
      >
        {{option.label}}
      </ShDropdownItem>
      <ShButton
        buttonColor="icon-outline-blue"
        :isIcon="true"
        buttonIcon="sh-icon-more"
        buttonSize="icon-more"
        slot="reference"
      ></ShButton>
    </ShDropdown>
</ShProductCard>`,
  methods: {action: action('clicked')}
}),{
  notes: 'A very very simple component',
});
