/* eslint-disable import/no-extraneous-dependencies */
import { storiesOf } from '@storybook/vue';
import { action } from '@storybook/addon-actions';
import { withKnobs, text, boolean, select, color } from '@storybook/addon-knobs';

import ShTag from '../components/sh-tag/ShTag';
import ShTagIcon from '../components/sh-tag/ShTagIcon';
import ShTagButton from '../components/sh-tag/ShTagButton';
import ShTagCreator from '../components/sh-tag/ShTagCreator';
import IconsList from '../helpers/IconsList';
import centered from '@storybook/addon-centered';

const stories = storiesOf('Tag', module);
const tagColorOptions = {
  blank: 'blank',
  proccessing: 'proccessing',
  red: 'red',
  lime: 'lime',
  blue: 'blue',
  'light-blue': 'light-blue',
  'light-pink': 'light-pink',
  pink: 'pink',
  purple: 'purple',
  turquoise: 'turquoise',
  green: 'green',
  grey: 'grey',
  'dark-grey': 'dark-grey',
  black: 'black',

  'blue-dark': 'blue-dark',

  'green-light': 'green-light',
  'green-dark': 'green-dark',

  'gray-light': 'gray-light',
  orange: 'orange',

  'pink-light': 'pink-light'
};
const buttonIconOptions = {
  none: '',
  'arrow-back': 'sh-icon-arrow-back',
  add: 'sh-icon-add',
  search: 'sh-icon-search'
};
const buttonTypeOptions = {
  button: 'button',
  submit: 'submit'
};
const buttonSizeOptions = {
  regular: '',
  small: 'small'
};

stories.addDecorator(
  withKnobs({
    escapeHTML: false
  })
);
stories.addDecorator(centered);
stories.add(
  'ShTag',
  () => {
    return {
      components: {ShTag},
      props: {
        tagContent: {default: text('tagContent', 'tag')},
        tagColor: {default: select('tagColor', tagColorOptions, 'blue')},
        isCloseable: {default: boolean('isCloseable', false)},
        isLoading: {default: boolean('isLoading', false)},
        isBadge: { default: boolean('isBadge', false)},
        isStockIndicator: {default: boolean('isStockIndicator', false)},
        isInStock: {default: boolean('isInStock', false)}
      },
      template: `
      <div style="width:300px">
        <ShTag 
          :tagContent='tagContent' 
          :tagColor='tagColor' 
          :isCloseable='isCloseable' 
          :isBadge='isBadge'
          :isInStock='isInStock'
          :isLoading='isLoading'
          @deleteTag='action'
          >
        </ShTag>
      </div>`,

      methods: {action: action('clicked')}
    }
  },
  {
    notes: 'A very simple component'
  }
);

stories.add(
  'ShTagIcon',
  () => {
    return {
      components: {ShTagIcon},
      props: {
        tagColor: {default: select('tagColor', tagColorOptions, '#06AAF5')},
        tagIcon: {default: select('tagIcon', IconsList, 'sh-icon-add')}
      },
      template: `<ShTagIcon
    :tagColor="tagColor"
    :tagIcon="tagIcon"
    >
    </ShTagIcon>`,
      methods: {action: action('clicked')}
    }
  },
  {
    notes: 'A very simple component'
  }
);

stories.add(
  'ShTagButton',
  () => {
    return {
      components: {ShTagButton},
      props: {
        tagContent: {default: text('tagContent', 'tag')},
        // tagColor: { default: select('tagColor', tagColorOptions, 'blue') },
        colorPreview: {default: color('colorPreview', '')},
        isCloseable: {default: boolean('isCloseable', false)},
        isEditable: {default: boolean('isEditable', false)},
        isDragable: {default: boolean('isDragable', false)},
        hasAttachment: {default: boolean('hasAttachment', false)},
        attachmentIcon: {default: select('attachmentIcon', IconsList, '')}
        // isStockIndicator: { default: boolean('isStockIndicator', false) },
        // isInStock: { default: boolean('isInStock', false) }
      },
      template:
        '<ShTagButton ' +
        ":tagContent='tagContent' " +
        ":isCloseable='isCloseable' " +
        ":isEditable='isEditable' " +
        ":colorPreview='colorPreview' " +
        ":isDragable='isDragable' " +
        ":hasAttachment='hasAttachment' " +
        ":attachmentIcon='attachmentIcon'" +
        "@attachmentClicked='action'" +
        "@attachmentHovered='attachmentHovered'" +
        "@editClicked='editClicked'" +
        "@deleteClicked='deleteClicked'" +
        '>' +
        '</ShTagButton>',
      methods: {
        action: action('attachmentClicked'),
        attachmentHovered: action('attachmentHovered'),
        editClicked: action('editClicked'),
        deleteClicked: action('deleteClicked')
      }
    }
  },
  {
    notes: 'A very simple component'
  }
);

stories.add(
  'Tag creator',
  () => {
    return {
      components: {ShTagCreator},
      data: () => {
        return {
          tags: [],
          validationOptions: text('validationOptions', 'email')
        };
      },
      template: `<ShTagCreator
    :tags="tags"
    :validationOptions="validationOptions"
    :submitOnBlur="true"
    @tagsChanged="updateTags"
    inputButtonContent="Zapisz"
  ></ShTagCreator>`,
      methods: {
        updateTags: function (tags) {
          this.tags = tags;
        }
      }
    }
  },
  {
    notes: 'A very simple component'
  }
);
const array = [];

for (let i = 0; i < 20; i++) {
  array.push('text ' + i);
}

array.push('tagSecond');
stories.add(
  'Tag creator with autocompleter',
  () => {
    return {
      components: {ShTagCreator},
      props: {
        tags: {default: []},
        validationOptions: {default: text('validationOptions', '')},
        autocompleteItems: {default: array}
      },
      template: `<ShTagCreator
    :tags="tags"
    :validationOptions="validationOptions"
    :submitOnBlur="true"
    :autocompleteItems="autocompleteItems"
    @tagsChanged="updateTags"
    inputButtonContent="Zapisz"
  ></ShTagCreator>`,
      methods: {
        updateTags: function (tags) {
          this.tags = tags;
        }
      }
    }
  },
  {
    notes: 'A very simple component'
  }
);
